package work.xuye.common.alert;

import com.dingtalk.api.DefaultDingTalkClient;
import com.dingtalk.api.DingTalkClient;
import com.dingtalk.api.request.OapiRobotSendRequest;
import com.dingtalk.api.response.OapiRobotSendResponse;
import com.taobao.api.ApiException;
import lombok.NoArgsConstructor;
import lombok.extern.slf4j.Slf4j;

/**
 * @author xuye
 * @since 2023/2/7 18:51
 **/
@Slf4j
@NoArgsConstructor
public class DingMessage {

    private String webhook;
    private String title;
    private String content;

    public static DingMessage init() {
        return new DingMessage();
    }


    public DingMessage to(String token) {
        this.webhook = "https://oapi.dingtalk.com/robot/send?access_token=" + token;
        return this;
    }

    public DingMessage withPreview(String title) {
        this.title = title;
        return this;
    }

    public DingMessage withContent(String content) {
        this.content = content;
        return this;
    }


    public void send() {
        DingTalkClient client = new DefaultDingTalkClient(this.webhook);
        OapiRobotSendRequest request = new OapiRobotSendRequest();
        request.setMsgtype("markdown");
        OapiRobotSendRequest.Markdown markdown = new OapiRobotSendRequest.Markdown();
        markdown.setTitle(this.title);
        markdown.setText(this.content);
        request.setMarkdown(markdown);
        try {
            OapiRobotSendResponse response = client.execute(request);
            if (response.getErrcode() != 0) {
                throw new RuntimeException(response.getBody());
            }
        } catch (RuntimeException | ApiException e) {
            log.error("钉钉消息发送失败", e);
        }
    }


}
