package work.xuye.common.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import work.xuye.common.annotation.ResponseBodyEnhanceController;
import work.xuye.common.db.entity.*;
import work.xuye.common.db.service.*;

import java.util.List;

/**
 * @author xuye
 * @since 2023/3/4 14:03
 **/
@Slf4j
@Api(tags = "配置信息")
@RequestMapping("/config")
@RequiredArgsConstructor
@ResponseBodyEnhanceController
public class ConfigController {


    private final TaskService taskService;
    private final TemplateService templateService;
    private final MappingService mappingService;
    private final DatasourceService datasourceService;
    private final StoreManager storeManager;


    @GetMapping("/task")
    @ApiOperation(value = "任务列表")
    public List<Task> taskList() {
        return taskService.list();
    }

    @GetMapping("/task/{id}")
    @ApiOperation(value = "任务")
    public Task task(@PathVariable Long id) {
        return taskService.getById(id);
    }

    @GetMapping("/template")
    @ApiOperation(value = "模板列表")
    public List<Template> templateList() {
        return templateService.list();
    }

    @GetMapping("/template/{id}")
    @ApiOperation(value = "模板")
    public Template template(@PathVariable Long id) {
        return templateService.getById(id);
    }

    @GetMapping("/mapping")
    @ApiOperation(value = "映射列表")
    public List<Mapping> mappingList() {
        return mappingService.list();
    }

    @GetMapping("/mapping/{id}")
    @ApiOperation(value = "映射")
    public Mapping mapping(@PathVariable Long id) {
        return mappingService.getById(id);
    }

    @GetMapping("/datasource")
    @ApiOperation(value = "数据源列表")
    public List<Datasource> datasourceList() {
        return datasourceService.list();
    }

    @GetMapping("/datasource/{id}")
    @ApiOperation(value = "数据源")
    public Datasource datasource(@PathVariable Long id) {
        return datasourceService.getById(id);
    }

    @GetMapping("/store")
    @ApiOperation(value = "变量列表")
    public List<Store> storeList() {
        return storeManager.getStoreService().list();
    }

    @GetMapping("/store/{namespace}/{key}")
    @ApiOperation(value = "变量")
    public Store store(@PathVariable String namespace, @PathVariable String key) {
        return storeManager.getValueFromNsByKey(namespace, key);
    }


}
