package work.xuye.common.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import work.xuye.common.annotation.ResponseBodyEnhanceController;
import work.xuye.common.properties.RedisProperties;
import work.xuye.common.service.RedisService;

import java.util.HashSet;
import java.util.Map;

/**
 * @author xuye
 * @since 2023/3/4 14:03
 **/
@Slf4j
@Api(tags = "缓存管理")
@RequestMapping("/cache")
@RequiredArgsConstructor
@ResponseBodyEnhanceController
public class RedisController {


    private final RedisService redisService;
    private final RedisProperties redisProperties;


    @GetMapping("/config")
    @ApiOperation(value = "查询缓存配置")
    public HashSet<RedisProperties.Item> getConfigKeys() {
        RedisProperties.Item urlKey = redisProperties.getUrl();
        RedisProperties.Item tokenKey = redisProperties.getMessage();
        RedisProperties.Item normal = redisProperties.getNormal();
        HashSet<RedisProperties.Item> result = new HashSet<>();
        result.add(urlKey);
        result.add(tokenKey);
        result.add(normal);
        return result;
    }


    @GetMapping("/{key}")
    @ApiOperation(value = "根据key查询缓存")
    public Map<Object, Object> getAll(@PathVariable String key) {
        return redisService.getAll(key);
    }

    @DeleteMapping("/{key}")
    @ApiOperation(value = "根据key清除缓存")
    public Boolean clear(@PathVariable String key) {
        return redisService.clear(key);
    }

    @DeleteMapping
    @ApiOperation(value = "清除所有缓存")
    public void clearAll() {
        redisService.clear();
    }


}
