package work.xuye.common.db.entity.vo;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import work.xuye.common.enums.DeleteCheckMode;
import work.xuye.common.enums.Status;

import java.util.List;

/**
 * @author xuye
 * @since 2023/2/17 23:41
 **/
@Data
@NoArgsConstructor
@AllArgsConstructor
public class SinkParams {

    /**
     * 模板名称表达式
     */
    private String templateNameExpression;
    /**
     * 根据哪个字段来判断这条数据是否需要执行update
     */
    private CheckUpdate checkUpdate;
    /**
     * 来判断这条数据是否需要执行delete
     */
    private CheckDelete checkDelete;

    private InsertConfig insertConfig;

    @Data
    public static class InsertConfig {
        /**
         * 前置检查
         */
        private List<String> predicates;

        /**
         * 后置行为
         */
        private List<String> postActions;
    }

    @Data
    public static class CheckUpdate {
        private Status status;
        private String fieldName;
        private String jsonPath;
    }

    @Data
    public static class CheckDelete {
        private Status status;
        private DeleteCheckMode mode;
        private DisappearConfig disappearConfig;
        private FixedValueConfig fixedValueConfig;
    }

    @Data
    public static class FixedValueConfig {

        /**
         * 满足断言条件的数据才会被处理
         */
        private List<String> predicates;

    }


    @Data
    public static class DisappearConfig {
        /**
         * 判断数据是否消失的条件
         */
        // todo 可优化为使用模板生成SQL
        private String condition;

        /**
         * 默认的消息通知模板
         */
        private String messageTemplate = "- [#{webSource}]-[#{title}](#{url})\n\r  #{postDate}\n\r";
        /**
         * 是否发送通知，默认发送通知
         */
        private boolean notificationEnabled = true;

        /**
         * 是否自动删除数据，默认自动删除
         */
        private boolean autoDeleteEnabled = true;

        /**
         * 当自动删除数据开关开启时，小于等于autoDeleteThreshold的数据会被自动删除
         */
        private Integer autoDeleteThreshold = 1;

        /**
         * 当未自动删除数据时，是否发送手动执行删除SQL的链接
         */
        private boolean sendExecuteSQLUrl = true;


    }

    @Data
    public static class FieldConfig {
        private String fieldName;
        private String jsonPath;

    }
}
