package work.xuye.common.db.entity.vo;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import work.xuye.common.enums.DbFieldType;

import java.util.List;

/**
 * @author xuye
 * @since 2023/3/4 14:00
 **/


@Data
@NoArgsConstructor
@AllArgsConstructor
public class TableTemplate {

    private String tableName;
    private String datasourceName;


    /**
     * 指的是数据库有默认值或者自增的字段，如果有，则在执行insert语句时，不需要填充该字段
     */
    private List<Field> autoValueFields;

    /**
     * 用于检索数据是否存在，该字段必须是索引字段
     */
    private Field uniqueField;

    /**
     * 如果该字段存在，则在执行insert语句时，会自动填充当前时间，需要根据fieldType来判断，比如如果是datetime,就now()，如果是timestamp就current_timestamp()
     */
    private Field createTimeField;

    /**
     * 如果该字段存在，则在执行update语句时，会自动填充当前时间,insert语句不会填充
     */
    private Field updateTimeField;

    /**
     * 如果发生 更新/删除 操作，需要更新该字段的值
     */
    private Field updateField;

    /**
     * 其他字段，指的是普通字段
     */
    private List<Field> otherFields;

    private LogicDeleteField logicDeleteField;


    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    public static class Field {
        /**
         * 字段名
         */
        private String fieldName;

        /**
         * 字段类型
         * 在生成SQL时需要额外关注，比如json类型的字段，需要考虑转义
         * 如果是字符串类型，需要考虑单引号的问题，如果是数字，就不用加单引号
         */
        private DbFieldType fieldType = DbFieldType.string;
        /**
         * 字段值
         */
        private Object value;

        /**
         * 字段校验表达式规则
         */
        private List<String> rules;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    @EqualsAndHashCode(callSuper = true)
    public static class LogicDeleteField extends Field {

        /**
         * 标识逻辑删除时，需要设置的值
         */
        private String deleteValue;

    }


}


