package work.xuye.common.db.service;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;
import org.springframework.util.ObjectUtils;
import work.xuye.common.db.entity.Sql;
import work.xuye.common.db.entity.vo.SqlStatements;

import java.util.List;

/**
 * @author xuye
 * @since 2023/4/1
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class SqlManager {

    @Getter
    private final SqlService sqlService;

    public Sql saveSql(String datasource, List<String> sqlList) {
        String md5 = this.getMd5(datasource, sqlList);
        // 根据md5查询是否存在，如果已经存在，直接返回
        Sql existedEntity = sqlService.lambdaQuery().eq(Sql::getCaptcha, md5).one();
        if (!ObjectUtils.isEmpty(existedEntity)) {
            return existedEntity;
        }
        SqlStatements statements = new SqlStatements();
        sqlList.forEach(statements::add);
        Sql sql = new Sql();
        sql.setDatasourceName(datasource);
        sql.setSqlStatements(statements);
        sql.setCaptcha(md5);
        sqlService.save(sql);
        return sql;
    }

    private String getMd5(String datasource, List<String> sqlList) {
        StringBuilder str = new StringBuilder();
        for (String sql : sqlList) {
            str.append(sql);
        }
        str.append(datasource);
        return DigestUtils.md5DigestAsHex(str.toString().getBytes());

    }

}
