package work.xuye.common.db.service;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import work.xuye.common.constant.CacheConstants;
import work.xuye.common.db.entity.Store;

/**
 * @author xuye
 * @since 2023/3/4 18:44
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class StoreManager {

    @Getter
    private final StoreService storeService;

    @Cacheable(value = CacheConstants.STORE, key = "#namespace + ':' + #key", unless = "#result == null")
    public Store getValueFromNsByKey(String namespace, String key) {
        return storeService.lambdaQuery()
                .eq(Store::getNamespace, namespace)
                .eq(Store::getKey, key)
                .one();
    }


    @CacheEvict(value = CacheConstants.STORE, key = "#namespace + ':' + #key")
    public Store upsert(String namespace, String key, String value) {
        Store store = this.getValueFromNsByKey(namespace, key);
        if (store == null) {
            store = new Store();
            store.setNamespace(namespace);
            store.setKey(key);
            store.setValue(value);
            storeService.save(store);
        } else {
            store.setValue(value);
            storeService.updateById(store);
        }
        return store;
    }

}
