package work.xuye.common.db.service;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;
import work.xuye.common.constant.CacheConstants;
import work.xuye.common.db.entity.Mapping;
import work.xuye.common.db.entity.Task;
import work.xuye.common.db.entity.Template;
import work.xuye.common.db.entity.vo.SinkParams;
import work.xuye.common.dto.TaskVO;
import work.xuye.common.spel.CustomFunction;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author xuye
 * @since 2023/3/4 18:44
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class TaskManager {

    public final CustomFunction cf;

    @Getter
    private final TaskService taskService;
    private final TemplateService templateService;
    private final MappingService mappingService;

    @Cacheable(value = CacheConstants.TASK, key = "#taskId", unless = "#result == null")
    public TaskVO getTaskInfoByTaskId(Integer taskId) {
        Task task = taskService.lambdaQuery()
                .eq(Task::getId, taskId)
                .one();
        Assert.notNull(task, "taskId" + taskId + "不存在");

        SinkParams sinkParams = task.getSinkParams();
        if (sinkParams != null) {
            List<Mapping> mappingList = mappingService.lambdaQuery()
                    .eq(Mapping::getName, task.getName())
                    .list();
            Assert.notEmpty(mappingList, "mapping" + task.getName() + "不存在");
            Map<String, Mapping> map = mappingList.stream().collect(Collectors.toMap(Mapping::getTemplate, mapping -> mapping));
            return new TaskVO(task, map);
        } else {
            return new TaskVO(task, null);
        }
    }

    @Cacheable(value = CacheConstants.TEMPLATE, key = "#templateName", unless = "#result == null")
    public Template getTemplateByName(String templateName) {
        Template template = templateService.lambdaQuery()
                .eq(Template::getName, templateName)
                .one();
        Assert.notNull(template, "模板" + templateName + "不存在");
        return template;
    }

}
