package work.xuye.common.dto;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;

import java.time.LocalDateTime;


@Data
public class R<T> {

    private boolean success;
    @JsonIgnore
    private String code;
    private String message;
    private T data;
    private LocalDateTime serverTime;


    public R(boolean success, String code, String message, T data) {
        this.success = success;
        this.code = code;
        this.message = message;
        this.data = data;
        this.serverTime = LocalDateTime.now();
    }

    private R() {
    }

    public static <T> R<T> success(String message) {
        return new R<>(true, "default-success", message, null);
    }

    public static <T> R<T> success(T data) {
        return new R<>(true, "default-success", "success", data);
    }

    public static <T> R<T> fail(T data) {
        return new R<>(false, "default-fail", "fail", data);
    }

    public static <T> R<T> fail(String message) {
        return new R<>(false, "default-fail", message, null);
    }

    public static <T> R<T> fail(T data, String message) {
        return new R<>(false, "default-fail", message, data);
    }
}
