package work.xuye.common.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;
import work.xuye.common.alert.DingMessage;
import work.xuye.common.enums.MessageType;
import work.xuye.common.properties.AlertProperties;
import work.xuye.common.store.MessageMD5Store;

import java.util.Objects;

/**
 * @author xuye
 * @since 2023/3/11 14:06
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class MessageService {

    private final MessageMD5Store messageMD5Store;

    private final AlertProperties alertProperties;


    public void sendMessage(MessageType messageType,
                            String title,
                            String subTitle,
                            String content) {
        StringBuilder result = new StringBuilder()
                .append("# ").append(title).append("\n");
        if (!ObjectUtils.isEmpty(subTitle)) {
            if (subTitle.length() > 500) {
                subTitle = subTitle.substring(0, 200) + " [.......] " + subTitle.substring(subTitle.length() - 200);
                subTitle = subTitle.replaceAll("`", "");
            }
            result.append("> ").append(subTitle).append("\n\r");
        }
        result.append(content).append("\n");

        boolean exist = messageMD5Store.exist(result.toString());
        String token = null;

        if (Objects.requireNonNull(messageType) == MessageType.exception) {
            token = alertProperties.getDingTalk().getExceptionChannel();
        } else {
            token = alertProperties.getDingTalk().getInfoChannel();
        }


        if (!exist) {
            DingMessage.init()
                    .to(token)
                    .withPreview(subTitle)
                    .withContent(result.toString())
                    .send();
            messageMD5Store.save(result.toString());
        } else {
            log.debug("短期内已经发送过相同的异常信息，不再发送: [{}]", result);
        }
    }
}
