package work.xuye.common.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.CommandLineRunner;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;
import work.xuye.common.properties.RedisProperties;

import java.util.Map;

/**
 * @author xuye
 * @since 2023/3/14 21:43
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class RedisService implements CommandLineRunner {


    private final RedisTemplate<String, String> redisTemplate;
    private final RedisProperties redisProperties;


    public Map<Object, Object> getAll(String key) {
        return redisTemplate.opsForHash().entries(key);
    }


    public Boolean clear(String key) {
        Boolean delete = redisTemplate.delete(key);
        if (!ObjectUtils.isEmpty(delete) && delete) {
            log.info("缓存key: [{}]清除成功", key);
        } else {
            log.debug("缓存key: [{}]清除失败", key);
        }
        return delete;
    }

    public void clear() {
        this.clear(redisProperties.getUrl().getKey());
        this.clear(redisProperties.getMessage().getKey());
    }

    @Override
    public void run(String... args) {
        this.clear();
    }
}
