package work.xuye.common.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import work.xuye.common.enums.ResourceStatus;
import work.xuye.common.store.UrlMD5MapStore;

/**
 * @author xuye
 * @since 2023/3/6 21:58
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class UrlMD5Service {

    private final UrlMD5MapStore urlMD5MapStore;

    public ResourceStatus getResourceStatus(String url, String md5) {
        String oldMd5 = urlMD5MapStore.get(url);
        if (oldMd5 == null) {
            return ResourceStatus.UNKNOWN;
        }
        if (oldMd5.equals(md5)) {
            return ResourceStatus.UNCHANGED;
        } else {
            return ResourceStatus.UPDATED;
        }
    }

    public void put(String url, String md5) {
        urlMD5MapStore.put(url, md5);
    }

    public void removeUrlMD5(String seedUrl) {
        Long aLong = urlMD5MapStore.removeKey(seedUrl);
        log.info("删除url对应的md5，url:{}, 删除条数:{}", seedUrl, aLong);
    }
}
