package work.xuye.common.spel;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.expression.Expression;
import org.springframework.expression.spel.standard.SpelExpressionParser;
import org.springframework.expression.spel.support.StandardEvaluationContext;
import org.springframework.messaging.Message;
import org.springframework.stereotype.Service;
import work.xuye.common.constant.ContextVariableConstants;
import work.xuye.common.constant.MessageConstants;
import work.xuye.common.db.entity.vo.MessageMapping;

import java.util.HashMap;
import java.util.List;

/**
 * @author xuye
 * @since 2023/3/4 18:30
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class SpringExpressionLanguageEvaluator {

    public final CustomFunction cf;

    private final SpelExpressionParser parser;


    public HashMap<String, Object> evaluate(MessageMapping messageMapping, Message<String> message) {
        StandardEvaluationContext context = new StandardEvaluationContext();
        String seedUrl = (String) message.getHeaders().get(MessageConstants.SEED_URL);
        String taskName = (String) message.getHeaders().get(MessageConstants.TASK_NAME);
        String payload = message.getPayload();
        HashMap<String, Object> result = new HashMap<>(32);
        List<MessageMapping.FieldMapping> fields = messageMapping.getFields();
        for (MessageMapping.FieldMapping field : fields) {
            context.setVariable(ContextVariableConstants.ITEM, payload);
            context.setVariable(ContextVariableConstants.SEED_URL, seedUrl);
            context.setVariable(ContextVariableConstants.TASK_NAME, taskName);
            Expression expression = parser.parseExpression(field.getExpression());
            Object value = null;
            try {
                value = expression.getValue(context, this);
            } catch (Exception e) {
                throw new RuntimeException("解析表达式出错，字段名：" + field.getFieldName() +
                        "，表达式：" + field.getExpression() + ", 错误消息：" + e.getMessage());
            }
            result.put(field.getFieldName(), value);
        }
        return result;
    }

    public Object evaluate(Object value, String expressionStr, Class<?> clazz) {
        StandardEvaluationContext context = new StandardEvaluationContext();
        context.setVariable(ContextVariableConstants.VALUE, value);
        Expression expression = parser.parseExpression(expressionStr);
        return expression.getValue(context, this, clazz);
    }

}
