package work.xuye.common.store;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.DigestUtils;
import work.xuye.common.properties.RedisProperties;

import java.util.concurrent.TimeUnit;

/**
 * @author xuye
 * @since 2023/3/6 21:56
 **/
@Slf4j
@Component
@RequiredArgsConstructor
public class MessageMD5Store {

    private final RedisTemplate<String, String> redisTemplate;

    private final RedisProperties redisProperties;

    public boolean exist(String message) {
        String md5Digest = DigestUtils.md5DigestAsHex(message.getBytes());
        return redisTemplate.opsForHash().hasKey(redisProperties.getMessage().getKey(), md5Digest);
    }

    public void save(String message) {
        String md5Digest = DigestUtils.md5DigestAsHex(message.getBytes());
        redisTemplate.opsForHash().put(redisProperties.getMessage().getKey(), md5Digest, message);
        redisTemplate.expire(redisProperties.getMessage().getKey(), redisProperties.getMessage().getExpireSeconds(), TimeUnit.MINUTES);
    }

}
