package work.xuye.common.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import work.xuye.common.db.entity.Task;
import work.xuye.common.db.entity.vo.TaskMiniVO;
import work.xuye.common.dto.TaskVO;
import work.xuye.common.properties.CommonProperties;

import java.util.Set;

/**
 * @author xuye
 * @since 2023/5/6 10:31
 **/
@Slf4j
@Component
public class DebugUtil {

    private static final Set<Integer> taskIds = Set.of(17);
    private static boolean DEBUG = false;


    @Autowired
    public DebugUtil(CommonProperties commonProperties) {
        if (commonProperties.isProduction()) {
            DEBUG = false;
        }
    }

    public static boolean isSkip(TaskMiniVO taskMiniVO) {
        return isSkip(taskMiniVO.getId(), taskMiniVO.getName());
    }

    public static boolean isSkip(Task task) {
        return isSkip(task.getId(), task.getName());
    }

    public static boolean isSkip(TaskVO taskVO) {
        return isSkip(taskVO.getTask().getId(), taskVO.getTask().getName());
    }

    public static boolean isSkip(Integer taskId) {
        if (!DEBUG) {
            return false;
        }
        if (!taskIds.contains(taskId)) {
            log.warn("skip task, [{}]", taskId);
            return true;
        }
        return false;
    }

    public static boolean isSkip(Integer taskId, String taskName) {
        if (!DEBUG) {
            return false;
        }
        if (!taskIds.contains(taskId)) {
            log.warn("skip task, [{}-{}]", taskId, taskName);
            return true;
        }
        return false;
    }
}
