package work.xuye.common.utils;

import lombok.extern.slf4j.Slf4j;

import java.net.HttpURLConnection;
import java.net.URL;

/**
 * @author xuye
 * @since 2023/3/27 21:50
 **/
@Slf4j
public class HttpUtil {

    public static void main(String[] args) {
        boolean is2xx = isHttpRes2XX("https://play.jddtv.com/watch/6c039740352b45169729b8a60e9cb294.m3u8?auth_token=1680155549-0-0-e9496cc36d146ec0b1100260d0a60c09");
        log.info("result:{}", is2xx);
    }

    public static boolean isHttpRes2XX(String url) {
        return isHttpRes2XXHelper(url, 5);
    }

    private static boolean isHttpRes2XXHelper(String url, int retries) {
        try {
            URL u = new URL(url);
            HttpURLConnection connection = (HttpURLConnection) u.openConnection();
            connection.setRequestMethod("GET");
            connection.setConnectTimeout(5000);
            connection.setReadTimeout(5000);
            connection.connect();
            int code = connection.getResponseCode();
            log.info("isHttpRes2XX handler, url: [{}], code: [{}]", url, code);
            if (code >= 300 && code < 400) {
                String location = connection.getHeaderField("Location");
                return retries > 0 && isHttpRes2XXHelper(location, retries - 1);
            }
            return code >= 200 && code < 300;
        } catch (Exception e) {
            if (retries <= 0) {
                log.error("isHttpRes2XX handler error, url: [{}]", url, e);
                throw new RuntimeException(e);
            }
            log.warn("isHttpRes2XX handler retrying, url: [{}], retries left: [{}]", url, retries);
            return isHttpRes2XXHelper(url, retries - 1);
        }
    }

}
