package work.xuye.common.utils;

import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.jayway.jsonpath.JsonPath;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

/**
 * @author xuye
 * @since 2023/3/11 19:12
 **/
@Slf4j
@Component
public class JsonPathUtil {

    private static Gson gson;

    public static boolean exist(String json, String path) {
        Object result = null;
        try {
            result = JsonPath.read(json, path);
        } catch (Exception e) {
            return false;
        }
        return !ObjectUtils.isEmpty(result);
    }

    public static JsonArray extractAsJsonArray(String json, String path, String seedUrl) {
        boolean exist = JsonPathUtil.exist(json, path);
        if (!exist) {
            log.debug("jsonPath: [{}] from [{}] not exist in json:\n{}", path, seedUrl, json);
            return new JsonArray();
        }
        Object read = JsonPathUtil.read(json, path);
        JsonElement jsonElement = gson.toJsonTree(read);
        if (jsonElement.isJsonArray()) {
            return jsonElement.getAsJsonArray();
        } else {
            JsonArray jsonArray = new JsonArray();
            jsonArray.add(jsonElement);
            return jsonArray;
        }
    }

    public static Object read(String json, String path) {
        Object read = null;
        try {
            read = JsonPath.read(json, path);
        } catch (Exception e) {
            log.error("jsonPath:{} extract error in json:{}", path, json);
            throw new RuntimeException(e);
        }
        return read;
    }

    public static boolean isJsonPath(String expression) {
        // todo 后续可优化成正则判断
        return expression.startsWith("$");
    }


    @Autowired
    public void setGson(Gson gson) {
        JsonPathUtil.gson = gson;
    }
}
