# 常用SQL

## 查询已注册任务状态

```sql
select name,
       description,
       CASE
           WHEN deleted = 0 THEN '🟢'
           WHEN deleted = 1 THEN '🔴'
           END                                                         AS '调度状态',
       CASE
           WHEN REPLACE(json_extract(sink_params, '$.checkUpdate.status'), '"', '') = 'on' THEN '🟢'
           WHEN REPLACE(json_extract(sink_params, '$.checkUpdate.status'), '"', '') = 'off' THEN '🔴'
           END                                                         as '是否检查更新',
       CASE
           WHEN REPLACE(json_extract(sink_params, '$.checkDelete.status'), '"', '') = 'on' THEN '🟢'
           WHEN REPLACE(json_extract(sink_params, '$.checkDelete.status'), '"', '') = 'off' THEN '🔴'
           END                                                         as '是否检查删除',
       REPLACE(json_extract(request_params, '$.url'), '"', '')         as 'URL',

       REPLACE(json_extract(sink_params, '$.dataSourceName'), '"', '') as '数据源名',
       REPLACE(json_extract(sink_params, '$.tableName'), '"', '')      as '表名'
from task;
```

## 查询爬虫库入库数量

```sql
select date(createDate) as 日期, spider, count(*) as count
from pyspider_resultdb.all_news
where JSON_EXTRACT(raw_data, '$.crawler') = 'snp'
  and createDate > curdate()
group by spider, 日期
order by count desc;
```

## 查询图文源今日入库数据

```sql
select title,
       url,
       content,
       webSource,
       spider,
       postDate,
       createDate,
       update_time
from all_news
where JSON_EXTRACT(raw_data, '$.crawler') = 'snp'
  and createDate > curdate()
order by createDate desc;
```

## 查询某个视频源今日入库数据

```sql
select v.title,
       t.`status`,
       v.url,
       v.`video_url`,
       v.`created_time`,
       t.`retry_count`
from `all_news_video_dycj` as v
         left join `task_news` as t on v.`url` = t.`url`
         left join `task_news_content` as c on t.`id` = c.id
where JSON_EXTRACT(v.raw_data, '$.crawler') = 'snp'
order by v.`created_time` desc
limit 50
```

## 根据spider查询视频处理状态

```sql
select v.status,
       v.publish_time,
       v.if_update,
       t.status,
       v.title,
       v.url,
       v.`video_url`,
       v.spider,
       v.`created_time`,
       v.`raw_data`,
       t.`status`,
       t.`retry_count`,
       c.*
from `all_news_video_dycj` as v
         left join `task_news` as t on v.`url` = t.`url`
         left join `task_news_content` as c on t.`id` = c.id
where v.spider = 'bosera_videos_api'
order by v.`created_time` desc
limit 100
```

## 根据spider清表重爬

```sql
delete v.*,c.*,t.*
from `all_news_video_dycj` as v
         inner join `task_news` as t on v.`url` = t.`url`
         inner join `task_news_content` as c on t.`id` = c.id
where v.spider = 'bosera_videos_api';
```