package work.xuye.helper.service;

import cn.hutool.db.Db;
import cn.hutool.db.Entity;
import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;
import work.xuye.helper.properties.HelperProperties;

import javax.annotation.PostConstruct;
import java.sql.SQLException;
import java.util.*;

/**
 * @author xuye
 * @since 2023/7/12 14:55
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class UpdateService implements ApplicationRunner {

    private final HelperProperties helperProperties;

    private final HashMap<String, HikariDataSource> dataSourceMap;

    @PostConstruct
    public void init() {

        Map<String, HelperProperties.DataSource> datasourceConfigMap = helperProperties.getDatasourceMap();
        for (String key : datasourceConfigMap.keySet()) {
            HelperProperties.DataSource source = datasourceConfigMap.get(key);
            HikariConfig config = new HikariConfig();
            config.setJdbcUrl(source.getUrl());
            config.setUsername(source.getUsername());
            config.setPassword(source.getPassword());
            HikariDataSource dataSource = new HikariDataSource(config);
            dataSourceMap.put(key, dataSource);


        }
    }

    public void start() throws SQLException {
        String sql = "select date(createDate) as date, spider, count(*) as count\n" +
                "from all_news\n" +
                "where JSON_EXTRACT(raw_data, '$.crawler') = 'snp'\n" +
                "  and createDate > curdate() - interval 1 day\n" +
                "group by spider, date\n" +
                "order by date desc, count desc;";


        Set<String> keys = dataSourceMap.keySet();

        HashMap<String, List<Entity>> map = new HashMap<>();

        for (String key : keys) {
            HikariDataSource dataSource = dataSourceMap.get(key);
            List<Entity> query = Db.use(dataSourceMap.get(key)).query(sql);
            map.put(key, query);
        }

        // Compare List<Entity> between different environments
        for (String key1 : keys) {
            for (String key2 : keys) {
                if (!key1.equals(key2)) {
                    List<Entity> list1 = map.get(key1);
                    List<Entity> list2 = map.get(key2);

                    for (Entity entity1 : list1) {
                        for (Entity entity2 : list2) {
                            String date1 = entity1.getStr("date");
                            String spider1 = entity1.getStr("spider");
                            int count1 = entity1.getInt("count");

                            String date2 = entity2.getStr("date");
                            String spider2 = entity2.getStr("spider");
                            int count2 = entity2.getInt("count");

                            if (date1.equals(date2) && spider1.equals(spider2) && count1 != count2) {
                                int diff = Math.abs(count1 - count2);
                                String more = count1 > count2 ? key1 : key2;
                                System.out.printf("@@@ [%s] [%s] %s: %d %s: %d, diff abs: %d, more: %s%n", date1, spider1, key1, count1, key2, count2, diff, more);
                                this.findDIff(spider1, date1);
                            }
                        }
                    }
                }
            }
            // todo 此处比较多个的话有遗漏，后续优化下
            break;
        }
    }


    public void findDIff(String spider, String date) throws SQLException {
        HashMap<String, List<String>> map = new HashMap<>();
        for (String key : dataSourceMap.keySet()) {
            HikariDataSource dataSource = dataSourceMap.get(key);

            String sql = "SELECT url FROM all_news WHERE spider = '" + spider + "' AND date(createDate) = '" + date + "';";
            List<Entity> resultList = Db.use(dataSource).query(sql);
            ArrayList<String> list = new ArrayList<>();
            for (Entity entity : resultList) {
                String url = entity.getStr("url");
                list.add(url);
            }
            map.put(key, list);
        }

        for (String s : map.keySet()) {
            this.compareEnvironments(map, s);
        }


    }

    public void compareEnvironments(HashMap<String, List<String>> map, String environment) throws SQLException {

        List<String> environmentList = map.get(environment);
        if (environmentList == null) {
            return;
        }
        for (String key : map.keySet()) {
            if (key.equals(environment)) {
                continue;
            }
            List<String> list = map.getOrDefault(key, new ArrayList<>());
            List<String> intersection = new ArrayList<>(list);
            intersection.retainAll(environmentList);

            List<String> different = new ArrayList<>(list);
            different.removeAll(intersection);

            if (!different.isEmpty()) {
                System.out.println("@@ 环境 " + environment + " 中，List " + key + " 中独有的元素有" + different.size() + "个");
                for (String s : different) {
                    getStatusByUrl(s);
                }
            }
        }
    }

    public void getStatusByUrl(String url) throws SQLException {
        String sql = "select spider from all_news where url='" + url + "';";
        for (String key : dataSourceMap.keySet()) {
            HikariDataSource dataSource = dataSourceMap.get(key);
            List<Entity> resultList = Db.use(dataSource).query(sql);
            if (ObjectUtils.isEmpty(resultList)) {
                System.err.println("⚠️ url: " + url + " not found in " + key);
            }
            if (resultList.size() == 1) {
                System.out.println("url [" + url + "] 被 [" + resultList.get(0).get("spider") + "] 提前抓取了");
            }
            if (resultList.size() > 1) {
                System.err.println("!!! url: " + url + " found in " + key + " " + resultList.size() + " times");
            }

        }
    }

    @Override
    public void run(ApplicationArguments args) throws Exception {
        this.start();
    }
}
