package work.xuye.scheduler.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.cloud.stream.function.StreamBridge;
import org.springframework.messaging.Message;
import org.springframework.messaging.support.MessageBuilder;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import work.xuye.common.constant.BindingConstants;
import work.xuye.common.constant.MessageConstants;
import work.xuye.common.constant.StageConstants;
import work.xuye.common.db.entity.Task;
import work.xuye.common.db.entity.vo.TaskMiniVO;
import work.xuye.common.db.service.TaskManager;
import work.xuye.common.db.service.TaskService;
import work.xuye.common.dto.TaskVO;
import work.xuye.common.enums.ProcessMode;
import work.xuye.common.utils.ID;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author xuye
 * @since 2023/3/12 22:57
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class IssueService implements ApplicationRunner {

    private final StreamBridge streamBridge;

    private final TaskManager taskManager;

    private final TaskService taskService;

    public TaskVO issueTask(Integer id) {
        TaskVO taskVO = taskManager.getTaskInfoByTaskId(id);
        Task task = taskVO.getTask();
        TaskMiniVO taskMiniVO = TaskMiniVO.builder()
                .id(task.getId())
                .name(task.getName())
                .build();
        Message<TaskMiniVO> message = MessageBuilder
                .withPayload(taskMiniVO)
                .setHeader(MessageConstants.CURRENT_STAGE, StageConstants.SCHEDULER)
                .setHeader(MessageConstants.TASK_TRACE_ID, ID.generate())
                .setHeader(MessageConstants.TASK_ID, task.getId())
                .setHeader(MessageConstants.TASK_NAME, task.getName())
                .build();
        boolean send = streamBridge.send(BindingConstants.TASK_OUT, message);
        if (!send) {
            throw new RuntimeException("send message failed");
        }
        ProcessMode processMode = task.getProcessMode();
        String emoji = processMode.equals(ProcessMode.DEBUG) ? "\uD83E\uDD16" : "";
        log.info("\uD83D\uDCE4 {} {}-{}",
                emoji,
                task.getId(),
                task.getName());
        return taskVO;
    }

    @Scheduled(cron = "${task.cron:0 0/1 * * * ?}")
    public void issueTask() {
        this.issueAllTask();
    }

    public ArrayList<TaskVO> issueAllTask() {
        log.info("--------------------");
        List<Task> list = taskService.list();
        Collections.shuffle(list);
        ArrayList<TaskVO> result = new ArrayList<>();
        list.forEach(task -> {
            result.add(this.issueTask(task.getId()));
        });
        return result;
    }

    @Override
    public void run(ApplicationArguments args) {
        this.issueAllTask();
    }
}
