package work.xuye.sink.service;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;
import org.springframework.util.ObjectUtils;
import work.xuye.common.db.entity.Sql;
import work.xuye.common.db.entity.vo.SqlResult;
import work.xuye.common.db.entity.vo.SqlStatements;
import work.xuye.common.db.service.SqlManager;
import work.xuye.common.enums.DMLResultEnum;

/**
 * @author xuye
 * @since 2023/4/1 22:11
 **/
@Slf4j
@Service
@RequiredArgsConstructor
public class SqlExecutor {

    private final SqlManager sqlManager;

    private final JdbcService jdbcService;

    public SqlResult executeSql(Integer id, String captcha) {
        Sql sqlObj = sqlManager.getSqlService().lambdaQuery().eq(Sql::getId, id).one();
        Assert.notNull(sqlObj, "sqlObj id " + id + " 不存在");
        Assert.isTrue(sqlObj.getCaptcha().equals(captcha), "验证码错误");
        if (!ObjectUtils.isEmpty(sqlObj.getRowsAffected())) {
            return new SqlResult(DMLResultEnum.EXECUTED, sqlObj);
        }
        int rowsAffected = 0;
        for (SqlStatements.item item : sqlObj.getSqlStatements().getDml()) {
            int i = jdbcService.executeSql(sqlObj.getDatasourceName(), item.getStatement());
            item.setRowsAffected(i);
            rowsAffected += i;
        }
        sqlObj.setRowsAffected(rowsAffected);
        sqlObj.setUpdateTime(null);
        sqlManager.getSqlService().updateById(sqlObj);
        return new SqlResult(DMLResultEnum.SUCCESS, sqlObj);
    }
}
