package work.xuye.transformer.transformer;

import com.google.gson.Gson;
import com.google.gson.JsonElement;
import com.google.gson.JsonParser;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * JSON标准规范要求字符串必须使用Unicode编码表示，但是不使用Unicode编码的字符串也是合法的JSON字符串
 * 为了避免后续由于JSON解析器的差异引发错误，这里统一将非Unicode编码的字符串转换为Unicode编码的字符串
 * 实现方式就是借助Gson的JsonParser将字符串转换为JsonElement，然后再转换为字符串，这样就可以保证字符串的格式是标准的JSON格式
 *
 * @author xuye
 * @since 2023/2/18 13:01
 **/
@Slf4j
@Component("jsonNormalize")
@RequiredArgsConstructor
public class JsonNormalizeTransformer implements MessageTransformer {

    private final Gson gson;

    @Override
    public String transform(String in, String seedUrl) {
        JsonElement jsonElement = JsonParser.parseString(in);
        String out = gson.toJson(jsonElement);
        log.debug("normalizeTransformer in: {}, out: {}", in, out);
        return out;
    }
}
